From a1c232cae3d8827691297d02d6f4ba980a805cd2 Mon Sep 17 00:00:00 2001
From: Lunny Xiao <xiaolunwen@gmail.com>
Date: Tue, 24 Oct 2023 13:58:11 +0800
Subject: [PATCH] Revert "fix orphan check for deleted branch (#27310)
 (#27320)" (#27763)

Because branch table is created until 1.21
Fix #27508
---
 modules/doctor/dbconsistency.go | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/modules/doctor/dbconsistency.go b/modules/doctor/dbconsistency.go
index a0637b8982..5486873556 100644
--- a/modules/doctor/dbconsistency.go
+++ b/modules/doctor/dbconsistency.go
@@ -168,9 +168,9 @@ func checkDBConsistency(ctx context.Context, logger log.Logger, autofix bool) er
 		// find protected branches without existing repository
 		genericOrphanCheck("Protected Branches without existing repository",
 			"protected_branch", "repository", "protected_branch.repo_id=repository.id"),
-		// find branches without existing repository
-		genericOrphanCheck("Branches without existing repository",
-			"branch", "repository", "branch.repo_id=repository.id"),
+		// find deleted branches without existing repository
+		genericOrphanCheck("Deleted Branches without existing repository",
+			"deleted_branch", "repository", "deleted_branch.repo_id=repository.id"),
 		// find LFS locks without existing repository
 		genericOrphanCheck("LFS locks without existing repository",
 			"lfs_lock", "repository", "lfs_lock.repo_id=repository.id"),